@@ -176,7 +176,7 @@ class TimeSeries(object):
 
             nc.setncattr("geospatial_bounds", "POINT({} {})".format(longitude, latitude))
             if not hasattr(nc, "geospatial_bounds_crs"):
-                nc.setncattr("geospatial_bounds_crs", "4326")
+                nc.setncattr("geospatial_bounds_crs", "EPSG:4326")
 
             # Metadata variables
             self.crs = nc.createVariable("crs", "i4")
@@ -289,6 +289,8 @@ class TimeSeries(object):
                 self.crs.geoid_name = sensor_vertical_datum
                 self.crs.vertical_datum = sensor_vertical_datum
                 self.crs.water_surface_reference_datum = sensor_vertical_datum
+                if not hasattr(self._nc, "geospatial_bounds_vertical_crs"):
+                    self._nc.setncattr("geospatial_bounds_vertical_crs", sensor_vertical_datum)
             except AttributeError:
                 pass
 
@@ -396,6 +398,8 @@ class TimeSeries(object):
                         self.crs.geoid_name = v
                         self.crs.vertical_datum = v
                         self.crs.water_surface_reference_datum = v
+                        if not hasattr(self._nc, "geospatial_bounds_vertical_crs"):
+                            self._nc.setncattr("geospatial_bounds_vertical_crs", v)
                     except AttributeError:
                         pass
 
@@ -405,6 +409,14 @@ class TimeSeries(object):
                     except BaseException:
                         logger.info('Could not add attribute {}: {}, skipping.'.format(k, v))
 
+        # Add a long name if it doesn't exist
+        if not hasattr(var, 'long_name'):
+            varunits = getattr(var, 'units', None)
+            vartitle = getattr(var, 'standard_name', getattr(var, 'name'))
+            vartitle = vartitle.title().replace('_', ' ')
+            if varunits is not None:
+                vartitle = '{} ({})'.format(vartitle, varunits)
+            var.long_name = vartitle
         var.grid_mapping = 'crs'
         var.platform = 'platform'
         var.ancillary_variables = 'platform'
